@@ -1,5 +1,18 @@
 psplitnorm <-
 function(x, mean = 0, sd = 1, skew = 0, sd1 = NULL, sd2 = NULL) {
+  n <- max(length(x),length(mean),length(sd),length(skew),length(sd1),length(sd2))
+  if(length(x)<n)
+    x[1:n]<-x
+  if(length(mean)<n)
+    mean[1:n]<-mean
+  if(length(sd)<n)
+    sd[1:n]<-sd
+  if(length(skew)<n)
+    skew[1:n]<-skew
+  if(length(sd1)<n)
+    sd1[1:n]<-sd1
+  if(length(sd2)<n)
+    sd2[1:n]<-sd2
   var0 <- sd^2
   if (!is.null(sd1)) 
     var1 <- sd1^2
@@ -13,14 +26,15 @@ function(x, mean = 0, sd = 1, skew = 0, sd1 = NULL, sd2 = NULL) {
     sd1 <- sqrt(var1)
     sd2 <- sqrt(var2)
   }
-  if (skew > 1 & skew < 1) 
+  if (any(findInterval(skew, c(-1,1), rightmost.closed=TRUE)!=1) )
     stop("skew must be between -1 and 1")
-  n <- max(length(x),length(mean),length(sd),length(skew),length(sd1),length(sd2))
   f <- rep(NA, n)
   c <- sqrt(2/pi)/(sd1 + sd2)
   k <- f 
-  k[] <- x
-  f[k <= mean] <- (c * sqrt(2 * pi) * sd1 * pnorm((k - mean)/sd1))[k <= mean]
-  f[k >  mean] <- (1 - c * sqrt(2 * pi) * sd2 * (1 - pnorm((k - mean)/sd2)))[k > mean]
+  k[] <- x #change name of x to match formula
+  k1 <- k <= mean
+  k2 <- k > mean
+  f[k1] <- (c[k1] * sqrt(2 * pi) * sd1[k1] * pnorm((k[k1] - mean[k1])/sd1[k1]))
+  f[k2] <- (1 - c[k2] * sqrt(2 * pi) * sd2[k2] * (1 - pnorm((k[k2] - mean[k2])/sd2[k2])))
   return(f)
 }
